rule win_cherry_picker_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.cherry_picker."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.cherry_picker"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 68???????? 68???????? a3???????? ffd6 69c0e8030000 68???????? }
            // n = 6, score = 300
            //   68????????           |                     
            //   68????????           |                     
            //   a3????????           |                     
            //   ffd6                 | call                esi
            //   69c0e8030000         | imul                eax, eax, 0x3e8
            //   68????????           |                     

        $sequence_1 = { 80fa3b 7503 83c9ff 8817 47 }
            // n = 5, score = 300
            //   80fa3b               | cmp                 dl, 0x3b
            //   7503                 | jne                 5
            //   83c9ff               | or                  ecx, 0xffffffff
            //   8817                 | mov                 byte ptr [edi], dl
            //   47                   | inc                 edi

        $sequence_2 = { 68???????? 56 89442420 ffd3 68???????? 56 }
            // n = 6, score = 300
            //   68????????           |                     
            //   56                   | push                esi
            //   89442420             | mov                 dword ptr [esp + 0x20], eax
            //   ffd3                 | call                ebx
            //   68????????           |                     
            //   56                   | push                esi

        $sequence_3 = { 8bf0 0fbec9 81e6ff000000 33f1 }
            // n = 4, score = 300
            //   8bf0                 | mov                 esi, eax
            //   0fbec9               | movsx               ecx, cl
            //   81e6ff000000         | and                 esi, 0xff
            //   33f1                 | xor                 esi, ecx

        $sequence_4 = { a1???????? 53 8b1d???????? 56 57 6aff }
            // n = 6, score = 300
            //   a1????????           |                     
            //   53                   | push                ebx
            //   8b1d????????         |                     
            //   56                   | push                esi
            //   57                   | push                edi
            //   6aff                 | push                -1

        $sequence_5 = { a3???????? 85c0 7512 68???????? 50 50 }
            // n = 6, score = 300
            //   a3????????           |                     
            //   85c0                 | test                eax, eax
            //   7512                 | jne                 0x14
            //   68????????           |                     
            //   50                   | push                eax
            //   50                   | push                eax

        $sequence_6 = { ff15???????? 8bf0 68???????? 56 ffd3 68???????? 56 }
            // n = 7, score = 300
            //   ff15????????         |                     
            //   8bf0                 | mov                 esi, eax
            //   68????????           |                     
            //   56                   | push                esi
            //   ffd3                 | call                ebx
            //   68????????           |                     
            //   56                   | push                esi

        $sequence_7 = { 6800010000 68???????? 68???????? 68???????? 68???????? ffd6 68???????? }
            // n = 7, score = 300
            //   6800010000           | push                0x100
            //   68????????           |                     
            //   68????????           |                     
            //   68????????           |                     
            //   68????????           |                     
            //   ffd6                 | call                esi
            //   68????????           |                     

        $sequence_8 = { a1???????? 56 6aff 50 8bf1 }
            // n = 5, score = 300
            //   a1????????           |                     
            //   56                   | push                esi
            //   6aff                 | push                -1
            //   50                   | push                eax
            //   8bf1                 | mov                 esi, ecx

        $sequence_9 = { ffd6 68???????? 6800010000 68???????? }
            // n = 4, score = 300
            //   ffd6                 | call                esi
            //   68????????           |                     
            //   6800010000           | push                0x100
            //   68????????           |                     

    condition:
        7 of them and filesize < 712704
}